package de.opalpiraten.scenepainter.tools;
import java.awt.Component;

/**
 * A Tool is a plugin for scenepainter. Tools can be added or removed
 * from the program without recompiling it. Generally each tool should
 * reside in a JAR file of it's own and declare a package under the 
 * de.opalpiraten.scenepainter.tools package. To hook into ScenePainter,
 * this interface must be implemented by at least one class in said 
 * JAR file. Upon program startup, ScenePainter will go through all the
 * supplied jars and watch for implementors of this interface.
 * <p>
 * A class implementing this interface must provide an empty constructor.
 * Upon loading it will be instantiated and it's getHook mehtod is called.
 */
public interface Tool {

  /**
   * This method is called by ScenePainter upon loading the Tool.
   * @return The component to plug into the tools menu. An instance of
   * JMenuItem is recommended. The returntype is defined to support tools
   * wanting to open up own submenus.
   */
  public Component getHook();
}
